@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: accents.c,v 1.1.1.1.2.1 2000/07/18 07:11:34 fredgo Exp $
+ $Id: accents.c,v 1.1.1.1.2.2 2000/08/03 11:28:09 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -116,6 +116,20 @@ CharMapping tilda [] = {
 StringMapping commands [] = {
     {"backslash", "\\"},
     {"ss", ""},
+    {"DH", ""},
+    {"dh", ""},
+    {"AE", ""},
+    {"ae", ""},
+    {"O",  ""},
+    {"o",  ""},
+    {"TH", ""},
+    {"th", ""},
+    {"guillemotleft",    ""},
+    {"guillemotright",   ""},
+    {"guilsingleft",     "<"},
+    {"guilsingright",    ">"},
+    {"textquestiondown", ""},
+    {"textexclamdown",   ""},
     {NULL, NULL}
 };
 
@@ -275,13 +289,12 @@ bibtex_accent_string (BibtexStruct * s,
 	    }
 	}
     }
-    else {
-	/* long command, use dictionnary to eventually map */
-	text = g_hash_table_lookup (commands_table, s->value.com);
 
-	if (text) {
-	    return g_strdup (text);
-	}
+    /* if not found, use dictionnary to eventually map */
+    text = g_hash_table_lookup (commands_table, s->value.com);
+
+    if (text) {
+      return g_strdup (text);
     }
 
     if (loss) * loss = TRUE;
